Declarative Inheritance — SQLAlchemy 1.4 Documentation

Release: 1.4.27 | Release Date: November 11, 2021

# SQLAlchemy 1.4 Documentation

Contents | Index

Search terms:

### SQLAlchemy ORM

- Object Relational Tutorial (1.x API)
- Mapper Configuration
- Relationship Configuration
- Querying Data, Loading Objects
- Using the Session
- Events and Internals
- ORM Extensions
  - Asynchronous I/O (asyncio)
  - Association Proxy
  - Automap
  - Baked Queries
  - Declarative Extensions
    - Declarative API
    - Basic Use
    - Declarative Inheritance
    - Mixin and Custom Base Classes
    - Configuring Relationships
    - Table Configuration
  - Mypy / Pep-484 Support for ORM Mappings
  - Mutation Tracking
  - Ordering List
  - Horizontal Sharding
  - Hybrid Attributes
  - Indexable
  - Alternate Class Instrumentation
- ORM Examples

# Declarative Inheritance

See Mapping Class Inheritance Hierarchies for this section.

Previous: Basic Use Next: Mixin and Custom Base Classes
© Copyright 2007-2021, the SQLAlchemy authors and contributors.

flambé! the dragon and The Alchemist image designs created and generously donated by Rotem Yaari.

Created using Sphinx 4.3.0.